/***********************************************************************************************
Author:			David Szybala
Program:		Project_Switcher.ms
Date:			1/18/11
Description:	This script is a dockable toolbar that can manipulate the current project folder.
***********************************************************************************************/

try(cui.UnRegisterDialogBar projectSwitchRollout)catch()
try (destroyDialog projectSwitchRollout) catch()
callbacks.removeScripts #filePostOpen id:#ProjectSwitcherCallback
global projectSwitchRollout
global projectPaths = #()

/**********************************************************************************************/
fn Set_Path_List =
(
	local projectIndex = 0
	
	appendIfUnique projectPaths (pathConfig.getCurrentProjectFolder())
	sort projectPaths
	projectIndex = findItem projectPaths (pathConfig.getCurrentProjectFolder())
	projectSwitchRollout.projectPathDrop.items = projectPaths
	projectSwitchRollout.projectPathDrop.height = projectPaths.count * 16
	projectSwitchRollout.projectPathDrop.selection = projectIndex
)--end fn

/**********************************************************************************************/
fn Set_Project_Path =
(
	local index = 0
	local projectPath = ""
	
	if (matchPattern maxFilePath pattern:"*scenes*") do
	(
		index = findString maxFilePath "scenes"
		projectPath = substring maxFilePath 1 (index - 2)
		pathConfig.setCurrentProjectFolder projectPath
	)--end if
	
	Set_Path_List()
)--end fn

/**********************************************************************************************/
(--put script into local scope
	local removePathRollout
	local projectIniFile = getDir #plugcfg + "\\ProjectSwitcher.ini"
	local projectRolloutPos
	
	/**********************************************************************************************/
	fn Set_Callback theState =
	(
		if theState then
			callbacks.addScript #filePostOpen "Set_Project_Path()" id:#ProjectSwitcherCallback
		else
			callbacks.removeScripts #filePostOpen id:#ProjectSwitcherCallback
	)--end fn

	/**********************************************************************************************/
	rollout removePathRollout "Remove Path(s)" width:315
	(
		multiListbox pathList "" width:290 height:18
		button removePathBtn "Remove Selected Path(s)" width:290 height:20
		
		on removePathRollout open do pathList.items = projectPaths
		
		on removePathBtn pressed do
		(
			local currentSelection = (pathList.selection as array)
			for i = currentSelection.count to 1 by -1 do deleteItem projectPaths currentSelection[i]
			Set_Path_List()
			destroyDialog removePathRollout
		)--end on
	)--end rollout
	
	/**********************************************************************************************/
	rollout projectSwitchRollout "Project Switcher"
	(
		checkbutton autoSwithChkBtn "Auto" pos:[5,2] width:40 height:16 checked:false
		dropdownlist projectPathDrop "" pos:[50,2] width:290 height:5
		button removePathBtn "Remove" pos:[345,2] width:50 height:16
		
		on projectSwitchRollout open do
		(
			local allPaths = getIniSetting projectIniFile "Projects"
			
			for i = 1 to allPaths.count do append projectPaths (getIniSetting projectIniFile "Projects" ("Path" + (i as string)))
			
			Set_Path_List()
			
			if (getIniSetting projectIniFile "Dialog" "Auto") == "true" do
			(
				autoSwithChkBtn.checked = true
				Set_Callback true
			)--end if
		)--end on
		
		on projectSwitchRollout moved pos do
			setIniSetting projectIniFile "Dialog" "Position" (pos as string)
			
		on projectSwitchRollout close do
		(
			local currentPaths = projectPathDrop.items
			delIniSetting projectIniFile "Projects"
			
			for i = 1 to currentPaths.count do
				setIniSetting projectIniFile "Projects" ("Path" + (i as string)) currentPaths[i]
			
			setIniSetting projectIniFile "Dialog" "Auto" (autoSwithChkBtn.checked as string)
			
			Set_Callback false
		)--end on
		
		on autoSwithChkBtn changed theState do
		(
			if theState then
				Set_Callback true
			else
				Set_Callback false
		)--end on
		
		on projectPathDrop selected itemNum do
			pathConfig.setCurrentProjectFolder projectPathDrop.items[itemNum]
		
		on removePathBtn pressed do createDialog removePathRollout
	)--end rollout
	projectRolloutPos = execute (getIniSetting projectIniFile "Dialog" "Position")
	if projectRolloutPos == OK do projectRolloutPos = [5,25]
	if projectRolloutPos.x > sysinfo.desktopsize.x - 415 do projectRolloutPos.x = sysinfo.desktopsize.x - 420
	if projectRolloutPos.y > sysinfo.desktopsize.y - 85 do projectRolloutPos.y = sysinfo.desktopsize.y - 85
	if projectRolloutPos.x < 0 do projectRolloutPos.x = 0 
	if projectRolloutPos.y < 0 do projectRolloutPos.y = 0
	createDialog projectSwitchRollout 415 25 0 0
	cui.RegisterDialogBar projectSwitchRollout style:#(#cui_dock_horz,#cui_floatable,#cui_handles)
	cui.DockDialogBar projectSwitchRollout #cui_dock_bottom
)--end local scope